pub trait Readable: Sized {
// Required method
fn read<R>(reader: &mut R) -> Result<Self, DecodeError>
where R: Read;
}Expand description
A trait that various LDK types implement allowing them to be read in from a Read.
This is not exported to bindings users as we only export serialization to/from byte arrays instead
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementations on Foreign Types
Sourceimpl Readable for Result<SocketAddress, u8>
impl Readable for Result<SocketAddress, u8>
fn read<R>(reader: &mut R) -> Result<Result<SocketAddress, u8>, DecodeError>where
R: Read,
Sourceimpl Readable for ContractDescriptor
impl Readable for ContractDescriptor
fn read<R>(r: &mut R) -> Result<ContractDescriptor, DecodeError>where
R: Read,
Sourceimpl Readable for ContractInfo
impl Readable for ContractInfo
fn read<R>(r: &mut R) -> Result<ContractInfo, DecodeError>where
R: Read,
Sourceimpl Readable for PayoutCurvePiece
impl Readable for PayoutCurvePiece
fn read<R>(r: &mut R) -> Result<PayoutCurvePiece, DecodeError>where
R: Read,
Sourceimpl Readable for NegotiationFields
impl Readable for NegotiationFields
fn read<R>(r: &mut R) -> Result<NegotiationFields, DecodeError>where
R: Read,
Sourceimpl Readable for OracleInfo
impl Readable for OracleInfo
fn read<R>(r: &mut R) -> Result<OracleInfo, DecodeError>where
R: Read,
Sourceimpl Readable for Vec<SocketAddress>
impl Readable for Vec<SocketAddress>
fn read<R>(r: &mut R) -> Result<Vec<SocketAddress>, DecodeError>where
R: Read,
Sourceimpl Readable for Vec<ChannelMonitorUpdate>
impl Readable for Vec<ChannelMonitorUpdate>
fn read<R>(r: &mut R) -> Result<Vec<ChannelMonitorUpdate>, DecodeError>where
R: Read,
Sourceimpl Readable for Vec<UpdateAddHTLC>
impl Readable for Vec<UpdateAddHTLC>
fn read<R>(r: &mut R) -> Result<Vec<UpdateAddHTLC>, DecodeError>where
R: Read,
Sourceimpl Readable for Vec<BlindedTail>
impl Readable for Vec<BlindedTail>
fn read<R>(r: &mut R) -> Result<Vec<BlindedTail>, DecodeError>where
R: Read,
Sourceimpl Readable for Duration
This is not exported to bindings users as Durations are simply mapped as ints.
impl Readable for Duration
This is not exported to bindings users as Durations are simply mapped as ints.